@@ -24,7 +24,7 @@ from typing import (
 from collections.abc import Collection, Iterable, Iterator, Mapping, Sequence
 
 import coverage
-from coverage import Coverage
+from coverage import Coverage, env
 from coverage.cmdline import CoverageScript
 from coverage.data import CoverageData
 from coverage.misc import import_local_file
@@ -60,7 +60,7 @@ def arcs_to_branches(arcs: Iterable[TArc]) -> dict[TLineNo, list[TLineNo]]:
 
 
 def branches_to_arcs(branches: dict[TLineNo, list[TLineNo]]) -> list[TArc]:
-    """Convert a dict od branches into a list of arcs."""
+    """Convert a dict of branches into a list of arcs."""
     return [(fromno, tono) for fromno, tonos in branches.items() for tono in tonos]
 
 
@@ -146,6 +146,7 @@ class CoverageTest(
     def check_coverage(
         self,
         text: str,
+        *,
         lines: Sequence[TLineNo] | Sequence[list[TLineNo]] | None = None,
         missing: str = "",
         report: str = "",
@@ -153,6 +154,7 @@ class CoverageTest(
         partials: Iterable[str] = (),
         branchz: str | None = None,
         branchz_missing: str | None = None,
+        branch: bool = True,
     ) -> Coverage:
         """Check the coverage measurement of `text`.
 
@@ -184,7 +186,7 @@ class CoverageTest(
             branches_missing = arcz_to_arcs(branchz_missing)
 
         # Start up coverage.py.
-        cov = coverage.Coverage(branch=True)
+        cov = coverage.Coverage(branch=branch)
         cov.erase()
         for exc in excludes or []:
             cov.exclude(exc)
@@ -207,8 +209,31 @@ class CoverageTest(
             else:
                 # lines is a list of possible line number lists, one of them
                 # must match.
-                for line_list in lines:
+                for i, line_list in enumerate(lines):   # pylint: disable=unused-variable
                     if statements == line_list:
+                        # PYVERSIONS: we might be able to trim down multiple
+                        # lines passed into this function.
+                        # Uncomment this code, run the whole test suite, then
+                        # sort /tmp/check_coverage_multi_line.out to group the
+                        # tests together and see if any of the `lines` elements
+                        # haven't been used.
+                        # One of the calls in test_successful_coverage passes
+                        # three `lines` elements, only one of which is right.
+                        # We need to keep that test until we can delete the
+                        # multi-lines option entirely.
+                        #
+                        # import inspect, platform
+                        # frinfo = inspect.getframeinfo(inspect.currentframe().f_back)
+                        # version = "{} {}.{}".format(
+                        #     platform.python_implementation(),
+                        #     *sys.version_info[:2],
+                        # )
+                        # with open("/tmp/check_coverage_multi_line.out", "a") as f:
+                        #     print(
+                        #         f"{frinfo.filename}@{frinfo.lineno}: "
+                        #         + f"lines {i + 1}/{len(lines)}: {version}",
+                        #         file=f,
+                        #     )
                         break
                 else:
                     assert False, f"None of the lines choices matched {statements!r}"
@@ -376,12 +401,14 @@ class CoverageTest(
     # https://salsa.debian.org/debian/pkg-python-coverage/-/blob/master/debian/patches/02.rename-public-programs.patch
     coverage_command = "coverage"
 
-    def run_command(self, cmd: str) -> str:
-        """Run the command-line `cmd` in a sub-process.
+    def run_command(self, cmd: str, *, status: int = 0) -> str:
+        """Run the command-line `cmd` in a subprocess.
 
-        `cmd` is the command line to invoke in a sub-process. Returns the
+        `cmd` is the command line to invoke in a subprocess. Returns the
         combined content of `stdout` and `stderr` output streams from the
-        sub-process.
+        subprocess.
+
+        Asserts that the exit status is `status` (default 0).
 
         See `run_command_status` for complete semantics.
 
@@ -390,11 +417,15 @@ class CoverageTest(
         Compare with `command_line`.
 
         """
-        _, output = self.run_command_status(cmd)
+        if status < 0 and env.LINUX:
+            # Mac properly returns -signal as the exit status. Linux returns 128 + signal.
+            status = 128 - status
+        actual_status, output = self.run_command_status(cmd)
+        assert actual_status == status
         return output
 
     def run_command_status(self, cmd: str) -> tuple[int, str]:
-        """Run the command-line `cmd` in a sub-process, and print its output.
+        """Run the command-line `cmd` in a subprocess, and print its output.
 
         Use this when you need to test the process behavior of coverage.
 
@@ -420,7 +451,7 @@ class CoverageTest(
         command_args = split_commandline[1:]
 
         if command_name == "python":
-            # Running a Python interpreter in a sub-processes can be tricky.
+            # Running a Python interpreter in a subprocesses can be tricky.
             # Use the real name of our own executable. So "python foo.py" might
             # get executed as "python3.3 foo.py". This is important because
             # Python 3.x doesn't install as "python", so you might get a Python
