@@ -15,6 +15,7 @@ import os.path
 import re
 import shutil
 import subprocess
+import sys
 import textwrap
 import warnings
 
@@ -24,8 +25,6 @@ from typing import (
 )
 from collections.abc import Iterable, Iterator
 
-import flaky
-
 import coverage
 from coverage import env
 from coverage.debug import DebugControl
@@ -33,25 +32,37 @@ from coverage.exceptions import CoverageWarning
 from coverage.types import TArc
 
 
-def run_command(cmd: str) -> tuple[int, str]:
+def _correct_encoding() -> str:
+    """Determine the right encoding to use for subprocesses."""
+    # Type checking trick due to "unreachable" being set
+    _locale_type_erased: Any = locale
+
+    encoding = os.device_encoding(1) or (
+        _locale_type_erased.getpreferredencoding()
+        if sys.version_info < (3, 11)
+        else _locale_type_erased.getencoding()
+    )
+    return encoding
+
+
+def subprocess_popen(cmd: str) -> subprocess.Popen[bytes]:
     """Run a command in a subprocess.
 
-    Returns the exit status code and the combined stdout and stderr.
+    Returns the Popen object.
 
     """
     # Subprocesses are expensive, but convenient, and so may be over-used in
     # the test suite.  Use these lines to get a list of the tests using them:
     if 0:  # pragma: debugging
-        with open("/tmp/processes.txt", "a") as proctxt:  # type: ignore[unreachable]
+        pth = "/tmp/processes.txt"                      # type: ignore[unreachable]
+        with open(pth, "a", encoding="utf-8") as proctxt:
             print(os.getenv("PYTEST_CURRENT_TEST", "unknown"), file=proctxt, flush=True)
 
-    encoding = os.device_encoding(1) or locale.getpreferredencoding()
-
     # In some strange cases (PyPy3 in a virtualenv!?) the stdout encoding of
     # the subprocess is set incorrectly to ascii.  Use an environment variable
     # to force the encoding to be the same as ours.
     sub_env = dict(os.environ)
-    sub_env['PYTHONIOENCODING'] = encoding
+    sub_env["PYTHONIOENCODING"] = _correct_encoding()
 
     proc = subprocess.Popen(
         cmd,
@@ -61,11 +72,21 @@ def run_command(cmd: str) -> tuple[int, str]:
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
     )
+    return proc
+
+
+def run_command(cmd: str) -> tuple[int, str]:
+    """Run a command in a subprocess.
+
+    Returns the exit status code and the combined stdout and stderr.
+
+    """
+    proc = subprocess_popen(cmd)
     output, _ = proc.communicate()
     status = proc.returncode
 
     # Get the output, and canonicalize it to strings with newlines.
-    output_str = output.decode(encoding).replace("\r", "")
+    output_str = output.decode(_correct_encoding()).replace("\r", "")
     return status, output_str
 
 
@@ -113,7 +134,7 @@ def make_file(
 
     if text and basename.endswith(".py") and SHOW_DIS:      # pragma: debugging
         os.makedirs("/tmp/dis", exist_ok=True)
-        with open(f"/tmp/dis/{basename}.dis", "w") as fdis:
+        with open(f"/tmp/dis/{basename}.dis", "w", encoding="utf-8") as fdis:
             print(f"# {os.path.abspath(filename)}", file=fdis)
             cur_test = os.getenv("PYTEST_CURRENT_TEST", "unknown")
             print(f"# PYTEST_CURRENT_TEST = {cur_test}", file=fdis)
@@ -367,21 +388,22 @@ class DebugControlString(DebugControl):
         return self.io.getvalue()
 
 
-TestMethod = Callable[[Any], None]
-
-def flaky_method(max_runs: int) -> Callable[[TestMethod], TestMethod]:
-    """flaky.flaky, but with type annotations."""
-    def _decorator(fn: TestMethod) -> TestMethod:
-        return cast(TestMethod, flaky.flaky(max_runs)(fn))
-    return _decorator
-
-
 def all_our_source_files() -> Iterator[tuple[Path, str]]:
     """Iterate over all of our own source files.
 
+    This is used in tests that need a bunch of Python code to analyze, so we
+    might as well use our own source code as the subject.
+
     Produces a stream of (filename, file contents) tuples.
     """
+    print(f"all_our_source_files: {coverage.__file__ = }")
     cov_dir = Path(coverage.__file__).parent.parent
+    if ".tox" in cov_dir.parts:
+        # We are in a tox-installed environment, look above the .tox dir to
+        # also find the uninstalled source files.
+        cov_dir = Path(os.fspath(cov_dir).partition(".tox")[0])
+
+    print(f"all_our_source_files: {os.path.abspath(cov_dir) = }")
     # To run against all the files in the tox venvs:
     #   for source_file in cov_dir.rglob("*.py"):
     for sub in [".", "benchmark", "ci", "coverage", "lab", "tests"]:
