@@ -181,6 +181,48 @@ class SimpleArcTest(CoverageTest):
             branchz_missing="",
         )
 
+    def test_bug_1991(self) -> None:
+        # A bytecode was missing a line number, causing a KeyError in sysmon.py.
+        self.check_coverage("""\
+            def func(x, y):
+                for size in (x or ()) if y else ():
+                    print(size)
+
+            func([5], True)
+            """,
+            branchz="2-1 23",
+            branchz_missing="",
+        )
+        assert self.stdout() == "5\n"
+
+    def test_bug_576(self) -> None:
+        if env.PYBEHAVIOR.pep626:
+            branchz = "34 36 89 8B"
+            branchz_missing = ""
+        else:
+            branchz = "34 38 89 8D"
+            branchz_missing = "38 8D"
+
+        self.check_coverage("""\
+            foo = True
+
+            if foo == True:
+                foo = False
+            else:  # pragma: no cover
+                pass
+
+            if foo == False:
+                foo = True
+            else:  # pragma: no cover
+                None
+
+            print("Done")
+            """,
+            branchz=branchz,
+            branchz_missing=branchz_missing,
+        )
+        assert self.stdout() == "Done\n"
+
 
 class WithTest(CoverageTest):
     """Arc-measuring tests involving context managers."""
@@ -188,7 +230,7 @@ class WithTest(CoverageTest):
     def test_with(self) -> None:
         self.check_coverage("""\
             def example():
-                with open("test", "w") as f:
+                with open("test", "w", encoding="utf-8") as f:
                     f.write("3")
                     a = 4
 
@@ -201,7 +243,7 @@ class WithTest(CoverageTest):
     def test_with_return(self) -> None:
         self.check_coverage("""\
             def example():
-                with open("test", "w") as f:
+                with open("test", "w", encoding="utf-8") as f:
                     f.write("3")
                     return 4
 
@@ -215,7 +257,7 @@ class WithTest(CoverageTest):
         # https://github.com/nedbat/coveragepy/issues/146
         self.check_coverage("""\
             for i in range(2):
-                with open("test", "w") as f:
+                with open("test", "w", encoding="utf-8") as f:
                     print(3)
                 print(4)
             print(5)
@@ -228,9 +270,9 @@ class WithTest(CoverageTest):
     def test_nested_with_return(self) -> None:
         self.check_coverage("""\
             def example(x):
-                with open("test", "w") as f2:
+                with open("test", "w", encoding="utf-8") as f2:
                     a = 3
-                    with open("test2", "w") as f4:
+                    with open("test2", "w", encoding="utf-8") as f4:
                         f2.write("5")
                         return 6
 
@@ -243,7 +285,7 @@ class WithTest(CoverageTest):
     def test_break_through_with(self) -> None:
         self.check_coverage("""\
             for i in range(1+1):
-                with open("test", "w") as f:
+                with open("test", "w", encoding="utf-8") as f:
                     print(3)
                     break
             print(5)
@@ -255,7 +297,7 @@ class WithTest(CoverageTest):
     def test_continue_through_with(self) -> None:
         self.check_coverage("""\
             for i in range(1+1):
-                with open("test", "w") as f:
+                with open("test", "w", encoding="utf-8") as f:
                     print(3)
                     continue
             print(5)
@@ -469,6 +511,23 @@ class LoopArcTest(CoverageTest):
             branchz_missing="17 25",
         )
 
+    def test_if_1(self) -> None:
+        lines = [1, 3, 6]
+        if env.PYBEHAVIOR.keep_constant_test:
+            lines.append(2)
+        self.check_coverage("""\
+            a = 1
+            if not not 1:
+                a = 3
+            else:
+                a = 5
+            assert a == 3
+            """,
+            lines=sorted(lines),
+            branchz="",
+            branchz_missing="",
+        )
+
     def test_while_1(self) -> None:
         # With "while 1", the loop knows it's constant.
         self.check_coverage("""\
@@ -485,6 +544,9 @@ class LoopArcTest(CoverageTest):
         )
 
     def test_while_true(self) -> None:
+        lines = [1, 3, 4, 5, 6, 7]
+        if env.PYBEHAVIOR.keep_constant_test:
+            lines.append(2)
         self.check_coverage("""\
             a, i = 1, 0
             while True:
@@ -494,10 +556,26 @@ class LoopArcTest(CoverageTest):
                 i += 1
             assert a == 4 and i == 3
             """,
+            lines=sorted(lines),
             branchz="34 36",
             branchz_missing="",
         )
 
+    def test_while_false(self) -> None:
+        lines = [1, 4]
+        if env.PYBEHAVIOR.keep_constant_test:
+            lines.append(2)
+        self.check_coverage("""\
+            a, i = 1, 0
+            while False:
+                1/0
+            assert a == 1 and i == 0
+            """,
+            lines=sorted(lines),
+            branchz="",
+            branchz_missing="",
+        )
+
     def test_while_not_false(self) -> None:
         self.check_coverage("""\
             a, i = 1, 0
@@ -1482,10 +1560,7 @@ class OptimizedIfTest(CoverageTest):
     def test_optimized_away_if_0(self) -> None:
         if env.PYBEHAVIOR.keep_constant_test:
             lines = [1, 2, 3, 4, 8, 9]
-            # 49 isn't missing because line 4 is matched by the default partial
-            # exclusion regex, and no branches are considered missing if they
-            # start from an excluded line.
-            branchz = "23 24 48 49"
+            branchz = "23 24"
             branchz_missing = "24"
         else:
             lines = [1, 2, 3, 8, 9]
@@ -1511,10 +1586,7 @@ class OptimizedIfTest(CoverageTest):
     def test_optimized_away_if_1(self) -> None:
         if env.PYBEHAVIOR.keep_constant_test:
             lines = [1, 2, 3, 4, 5, 6, 9]
-            # 49 isn't missing because line 4 is matched by the default partial
-            # exclusion regex, and no branches are considered missing if they
-            # start from an excluded line.
-            branchz = "23 24 45 49 56 59"
+            branchz = "23 24 56 59"
             branchz_missing = "24 59"
         else:
             lines = [1, 2, 3, 5, 6, 9]
@@ -1540,15 +1612,8 @@ class OptimizedIfTest(CoverageTest):
     def test_optimized_away_if_1_no_else(self) -> None:
         if env.PYBEHAVIOR.keep_constant_test:
             lines = [1, 2, 3, 4, 5]
-            # 25 isn't missing because line 2 is matched by the default partial
-            # exclusion regex, and no branches are considered missing if they
-            # start from an excluded line.
-            branchz = "23 25"
-            branchz_missing = ""
         else:
             lines = [1, 3, 4, 5]
-            branchz = ""
-            branchz_missing = ""
         self.check_coverage("""\
             a = 1
             if 1:
@@ -1557,22 +1622,15 @@ class OptimizedIfTest(CoverageTest):
             d = 5
             """,
             lines=lines,
-            branchz=branchz,
-            branchz_missing=branchz_missing,
+            branchz="",
+            branchz_missing="",
         )
 
     def test_optimized_if_nested(self) -> None:
         if env.PYBEHAVIOR.keep_constant_test:
             lines = [1, 2, 8, 11, 12, 13, 14, 15]
-            branchz = "28 2F 8B 8F"
-            branchz_missing = ""
-            # 2F and 8F aren't missing because they're matched by the default
-            # partial exclusion regex, and no branches are considered missing
-            # if they start from an excluded line.
         else:
             lines = [1, 12, 14, 15]
-            branchz = ""
-            branchz_missing = ""
 
         self.check_coverage("""\
             a = 1
@@ -1592,8 +1650,8 @@ class OptimizedIfTest(CoverageTest):
             i = 15
             """,
             lines=lines,
-            branchz=branchz,
-            branchz_missing=branchz_missing,
+            branchz="",
+            branchz_missing="",
         )
 
     def test_dunder_debug(self) -> None:
@@ -1615,10 +1673,8 @@ class OptimizedIfTest(CoverageTest):
     def test_if_debug(self) -> None:
         if env.PYBEHAVIOR.optimize_if_debug:
             branchz = "12 1. 24 26"
-            branchz_missing = ""
         else:
-            branchz = "12 23 31 34 26 1."
-            branchz_missing = "31"
+            branchz = "12 1. 23 26"
         self.check_coverage("""\
             for value in [True, False]:
                 if value:
@@ -1628,7 +1684,7 @@ class OptimizedIfTest(CoverageTest):
                     x = 6
             """,
             branchz=branchz,
-            branchz_missing=branchz_missing,
+            branchz_missing="",
         )
 
     def test_if_not_debug(self) -> None:
@@ -1646,7 +1702,7 @@ class OptimizedIfTest(CoverageTest):
                         lines.add(5)
                 else:
                     lines.add(7)
-            assert lines == set([7])
+            assert lines == {7}
             """,
             branchz=branchz,
         )
@@ -2104,9 +2160,13 @@ class ExcludeTest(CoverageTest):
             e = 7
             if e:#\tpragma:\tno branch
                 f = 9
+            import typing
+            if typing.TYPE_CHECKING:    # only for mypy
+                g = 12
             """,
-            [1,2,3,4,5,6,7,8,9],
-            branchz="23 24 56 57 89 8.",
+            lines=[1,2,3,4,5,6,7,8,9,10,11,12],
+            missing="12",
+            branchz="23 24 56 57 89 8A BC B.",
             branchz_missing="",
         )
 
@@ -2118,7 +2178,7 @@ class ExcludeTest(CoverageTest):
                 break
             assert c == 5-2
             """,
-            [1,2,3,4,5],
+            lines=[1,2,3,4,5],
             partials=["only some"],
             branchz="23 25", branchz_missing="",
         )
